get_executable_path

Function get_executable_path 

pub fn get_executable_path() -> Option<PathBuf>
Available on crate feature assets only.
Returns the path to the executable. This is useful for loading assets in CLI based applications.

Platform specific behavior

On supported platforms this returns the path to the current executing program. Supported platforms are:

  • Any Linux/Unix with a procfs,
  • macOS,
  • iOS

Returns None if there is a system issue, ex: the system didn’t return a proper path to the current executing application. This should rarely occur.