pub struct IncompatibleDependency {
pub name: String,
pub actual_version: String,
pub expected_version: String,
}Available on crate feature
module only.Expand description
Describes an incompatible dependency (a dependency which may produce ABI issues) when attempting to load Rust based modules.
Fields
name: StringThe name of the dependency which is incompatible.
actual_version: StringThe version of the dependency imported by the module which failed to load.
expected_version: StringThe version of the dependency used by this ModuleLoader.