pub enum Error {
Io(Error),
Unsupported,
Other(String),
}Available on crate feature
open only.Expand description
Error cases for open functions.
Variants
Io(Error)
An IO error.
This error typically occurs when the URL object failed to create its OsString representation or when getting the absolute path of a file.
Unsupported
The current platform does not support this operation.
This error may be thrown for example, when calling show_in_files on iOS or on Windows. Another case is when open is called with a web page on a Linux system with no xdg-open script/binary present in the PATH.
Other(String)
Another kind of system error.
This variant is typically returned in case of DBus error under non Apple/Android unix systems.