pub struct Instant(/* private fields */);Available on crate feature
time only.Expand description
This is a replacement of Instant for real-time systems
Platform specific behavior
- On all unixes (including macOS), this uses
clock_gettimewith CLOCK_MONOTONIC_RAW instead ofCLOCK_MONOTONICwhich Rust decided not to do and leave broken (see https://github.com/rust-lang/rust/issues/77807). - On windows, this falls back to Instant which uses the WinAPI
QueryPerformanceCounter.
Implementations